package VMOMI::HostReplayUnsupportedReason;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
